"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const url = __importStar(require("url"));
const superagent = __importStar(require("superagent"));
const converter_1 = require("./converter");
class WebhookResponse {
    constructor(status, headers, body) {
        this.status = status;
        this.headers = headers;
        this.body = body;
    }
}
exports.WebhookResponse = WebhookResponse;
class WebhookError {
    constructor(status, headers, body, error) {
        this.status = status;
        this.headers = headers;
        this.body = body;
        this.error = error;
    }
}
exports.WebhookError = WebhookError;
class Webhook {
    static send(req) {
        return new Promise((resolve, reject) => {
            const parsed = url.parse(req.url, true);
            const webhookUrl = "https://chat.googleapis.com/v1/spaces/" + req.params["space"] + "/messages" + parsed.search;
            superagent.post(webhookUrl)
                .set("Content-Type", "application/json; charset=UTF-8")
                .send(converter_1.Converter.convert(req.body))
                .then((response) => {
                resolve(new WebhookResponse(response.status, response.header, response.body));
            })
                .catch((err) => {
                reject(new WebhookError(err.status, err.header, err.body, err.response && err.response.text ? JSON.parse(err.response.text) : "Request failed"));
            });
        });
    }
    static express(req, res, next) {
        Webhook.send(req)
            .then(value => res
            .status(value.status)
            .json(value))
            .catch(reason => {
            if (!(reason instanceof WebhookError)) {
                return next(reason);
            }
            return res
                .status(reason.status)
                .json(reason);
        });
    }
}
exports.Webhook = Webhook;
//# sourceMappingURL=webhook.js.map